diff --git a/python/psi-api/src/com/jetbrains/python/psi/PyElementVisitor.java b/python/psi-api/src/com/jetbrains/python/psi/PyElementVisitor.java
index 8bbfa949a0c3..d9e1f238dfdf 100644
--- a/python/psi-api/src/com/jetbrains/python/psi/PyElementVisitor.java
+++ b/python/psi-api/src/com/jetbrains/python/psi/PyElementVisitor.java
@@ -213,7 +213,7 @@ public class PyElementVisitor extends PsiElementVisitor {
visitPyElement(node);
}
- public void visitPyFormattedStringNode(PyFormattedStringNode node) {
+ public void visitPyFormattedStringElement(PyFormattedStringElement node) {
visitPyElement(node);
}
diff --git a/python/psi-api/src/com/jetbrains/python/psi/PyFormattedStringNode.java b/python/psi-api/src/com/jetbrains/python/psi/PyFormattedStringElement.java
similarity index 87%
rename from python/psi-api/src/com/jetbrains/python/psi/PyFormattedStringNode.java
rename to python/psi-api/src/com/jetbrains/python/psi/PyFormattedStringElement.java
index 22ee69b4b94d..134d7fff0f9e 100644
--- a/python/psi-api/src/com/jetbrains/python/psi/PyFormattedStringNode.java
+++ b/python/psi-api/src/com/jetbrains/python/psi/PyFormattedStringElement.java
@@ -9,7 +9,7 @@ import java.util.List;
/**
* Represents an f-string, a special kind of interpolated string literal introduced in Python 3.6.
*
- * Unlike {@link PyLiteralStringNode} these elements are composite and consist of several kinds of tokens
+ * Unlike {@link PyPlainStringElement} these elements are composite and consist of several kinds of tokens
* and normal PSI trees for embedded expressions.
*
* @see com.jetbrains.python.PyTokenTypes#FSTRING_START
@@ -17,7 +17,7 @@ import java.util.List;
* @see PyFStringFragment
* @see com.jetbrains.python.PyTokenTypes#FSTRING_END
*/
-public interface PyFormattedStringNode extends PyRichStringNode, PyElement {
+public interface PyFormattedStringElement extends PyStringElement, PyElement {
/**
* Returns a list of replacement fields containing expressions which values should be embedded into this literal content.
*
@@ -33,7 +33,7 @@ public interface PyFormattedStringNode extends PyRichStringNode, PyElement {
* expression fragments.
*
* These ranges don't include literal format specifier parts of fragments and should be completely
- * covered by {@link PyRichStringNode#getContentRange()}.
+ * covered by {@link PyStringElement#getContentRange()}.
*
* For instance, for the following f-string:
*
diff --git a/python/psi-api/src/com/jetbrains/python/psi/PyLiteralStringNode.java b/python/psi-api/src/com/jetbrains/python/psi/PyPlainStringElement.java
similarity index 88%
rename from python/psi-api/src/com/jetbrains/python/psi/PyLiteralStringNode.java
rename to python/psi-api/src/com/jetbrains/python/psi/PyPlainStringElement.java
index f3e540652b35..ceb62fc0017f 100644
--- a/python/psi-api/src/com/jetbrains/python/psi/PyLiteralStringNode.java
+++ b/python/psi-api/src/com/jetbrains/python/psi/PyPlainStringElement.java
@@ -15,5 +15,5 @@ package com.jetbrains.python.psi;
*
{@code '\u0041 \x41 \N{LATIN CAPITAL LETTER A}'}
*
*/
-public interface PyLiteralStringNode extends PyRichStringNode {
+public interface PyPlainStringElement extends PyStringElement {
}
diff --git a/python/psi-api/src/com/jetbrains/python/psi/PyRichStringNode.java b/python/psi-api/src/com/jetbrains/python/psi/PyStringElement.java
similarity index 93%
rename from python/psi-api/src/com/jetbrains/python/psi/PyRichStringNode.java
rename to python/psi-api/src/com/jetbrains/python/psi/PyStringElement.java
index c0578fd82fa5..1768a7e78ee6 100644
--- a/python/psi-api/src/com/jetbrains/python/psi/PyRichStringNode.java
+++ b/python/psi-api/src/com/jetbrains/python/psi/PyStringElement.java
@@ -11,10 +11,10 @@ import java.util.List;
* A common interface containing utility methods shared among both plain string literals
* (i.e. those that don't have "f" prefix) and formatted literals (f-strings).
*
- * @see PyLiteralStringNode
- * @see PyFormattedStringNode
+ * @see PyPlainStringElement
+ * @see PyFormattedStringElement
*/
-public interface PyRichStringNode extends PsiElement {
+public interface PyStringElement extends PsiElement {
/**
* Returns string prefix, e.g. "UR", "b", "f", etc.
@@ -95,7 +95,7 @@ public interface PyRichStringNode extends PsiElement {
/**
* Returns whether this string literal contains "f" or "F" prefix.
*
- * It can be used as a counterpart for {@code this isinstance PyFormattedStringNode}, since only this implementation
+ * It can be used as a counterpart for {@code this isinstance PyFormattedStringElement}, since only this implementation
* is allowed to have such prefix.
*/
boolean isFormatted();
diff --git a/python/src/com/jetbrains/python/PyElementTypes.java b/python/src/com/jetbrains/python/PyElementTypes.java
index 507eafd6654c..4b3f960d9cbe 100644
--- a/python/src/com/jetbrains/python/PyElementTypes.java
+++ b/python/src/com/jetbrains/python/PyElementTypes.java
@@ -151,7 +151,7 @@ public interface PyElementTypes {
TokenSet CLASS_OR_FUNCTION = TokenSet.create(CLASS_DECLARATION, FUNCTION_DECLARATION);
TokenSet IMPORT_STATEMENTS = TokenSet.create(IMPORT_STATEMENT, FROM_IMPORT_STATEMENT);
- PyElementType FSTRING_NODE = new PyElementType("FSTRING_NODE", PyFormattedStringNodeImpl.class);
+ PyElementType FSTRING_NODE = new PyElementType("FSTRING_NODE", PyFormattedStringElementImpl.class);
PyElementType FSTRING_FRAGMENT = new PyElementType("FSTRING_FRAGMENT", PyFStringFragmentImpl.class);
PyElementType FSTRING_FRAGMENT_FORMAT_PART = new PyElementType("FSTRING_FRAGMENT_FORMAT_PART", PyFStringFragmentFormatPartImpl.class);
}
diff --git a/python/src/com/jetbrains/python/psi/PyUtil.java b/python/src/com/jetbrains/python/psi/PyUtil.java
index 8e6e48c07aae..996f257de469 100644
--- a/python/src/com/jetbrains/python/psi/PyUtil.java
+++ b/python/src/com/jetbrains/python/psi/PyUtil.java
@@ -1917,7 +1917,7 @@ public class PyUtil {
public StringNodeInfo(@NotNull ASTNode node) {
final IElementType nodeType = node.getElementType();
- // TODO Migrate to newer PyRichStringNode API
+ // TODO Migrate to newer PyStringElement API
if (!PyTokenTypes.STRING_NODES.contains(nodeType) && nodeType != PyElementTypes.FSTRING_NODE) {
throw new IllegalArgumentException("Node must be valid Python string literal token, but " + nodeType + " was given");
}
diff --git a/python/src/com/jetbrains/python/psi/impl/PyFormattedStringNodeImpl.java b/python/src/com/jetbrains/python/psi/impl/PyFormattedStringElementImpl.java
similarity index 94%
rename from python/src/com/jetbrains/python/psi/impl/PyFormattedStringNodeImpl.java
rename to python/src/com/jetbrains/python/psi/impl/PyFormattedStringElementImpl.java
index cf35ab3bf8fc..a5719b1515b8 100644
--- a/python/src/com/jetbrains/python/psi/impl/PyFormattedStringNodeImpl.java
+++ b/python/src/com/jetbrains/python/psi/impl/PyFormattedStringElementImpl.java
@@ -13,22 +13,22 @@ import com.jetbrains.python.PyElementTypes;
import com.jetbrains.python.PyTokenTypes;
import com.jetbrains.python.psi.PyElementVisitor;
import com.jetbrains.python.psi.PyFStringFragment;
-import com.jetbrains.python.psi.PyFormattedStringNode;
+import com.jetbrains.python.psi.PyFormattedStringElement;
import com.jetbrains.python.psi.PyStringLiteralUtil;
import org.jetbrains.annotations.NotNull;
import java.util.ArrayList;
import java.util.List;
-public class PyFormattedStringNodeImpl extends PyElementImpl implements PyFormattedStringNode {
+public class PyFormattedStringElementImpl extends PyElementImpl implements PyFormattedStringElement {
- public PyFormattedStringNodeImpl(ASTNode astNode) {
+ public PyFormattedStringElementImpl(ASTNode astNode) {
super(astNode);
}
@Override
protected void acceptPyVisitor(PyElementVisitor pyVisitor) {
- pyVisitor.visitPyFormattedStringNode(this);
+ pyVisitor.visitPyFormattedStringElement(this);
}
@NotNull
diff --git a/python/src/com/jetbrains/python/psi/impl/PyLiteralStringNodeImpl.java b/python/src/com/jetbrains/python/psi/impl/PyPlainStringElementImpl.java
similarity index 89%
rename from python/src/com/jetbrains/python/psi/impl/PyLiteralStringNodeImpl.java
rename to python/src/com/jetbrains/python/psi/impl/PyPlainStringElementImpl.java
index 8b6e84a332ba..4cb40adabbe7 100644
--- a/python/src/com/jetbrains/python/psi/impl/PyLiteralStringNodeImpl.java
+++ b/python/src/com/jetbrains/python/psi/impl/PyPlainStringElementImpl.java
@@ -5,7 +5,7 @@ import com.intellij.openapi.util.TextRange;
import com.intellij.openapi.util.text.StringUtil;
import com.intellij.psi.impl.source.tree.LeafPsiElement;
import com.intellij.psi.tree.IElementType;
-import com.jetbrains.python.psi.PyLiteralStringNode;
+import com.jetbrains.python.psi.PyPlainStringElement;
import com.jetbrains.python.psi.PyStringLiteralUtil;
import org.jetbrains.annotations.NotNull;
@@ -14,8 +14,8 @@ import java.util.List;
/**
* @author Mikhail Golubev
*/
-public class PyLiteralStringNodeImpl extends LeafPsiElement implements PyLiteralStringNode {
- public PyLiteralStringNodeImpl(@NotNull IElementType type, CharSequence text) {
+public class PyPlainStringElementImpl extends LeafPsiElement implements PyPlainStringElement {
+ public PyPlainStringElementImpl(@NotNull IElementType type, CharSequence text) {
super(type, text);
}
diff --git a/python/src/com/jetbrains/python/psi/impl/PyStringLiteralDecoder.java b/python/src/com/jetbrains/python/psi/impl/PyStringLiteralDecoder.java
index dd788006233b..d21c0bbb9b5d 100644
--- a/python/src/com/jetbrains/python/psi/impl/PyStringLiteralDecoder.java
+++ b/python/src/com/jetbrains/python/psi/impl/PyStringLiteralDecoder.java
@@ -7,7 +7,7 @@ import com.intellij.psi.PsiFile;
import com.jetbrains.python.psi.FutureFeature;
import com.jetbrains.python.psi.LanguageLevel;
import com.jetbrains.python.psi.PyFile;
-import com.jetbrains.python.psi.PyRichStringNode;
+import com.jetbrains.python.psi.PyStringElement;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
@@ -59,9 +59,9 @@ public class PyStringLiteralDecoder {
return map;
}
- private final PyRichStringNode myNode;
+ private final PyStringElement myNode;
- public PyStringLiteralDecoder(@NotNull PyRichStringNode node) {
+ public PyStringLiteralDecoder(@NotNull PyStringElement node) {
myNode = node;
}
diff --git a/python/src/com/jetbrains/python/psi/impl/PyStringLiteralExpressionImpl.java b/python/src/com/jetbrains/python/psi/impl/PyStringLiteralExpressionImpl.java
index 70b243ed586d..28746977cca6 100644
--- a/python/src/com/jetbrains/python/psi/impl/PyStringLiteralExpressionImpl.java
+++ b/python/src/com/jetbrains/python/psi/impl/PyStringLiteralExpressionImpl.java
@@ -83,7 +83,7 @@ public class PyStringLiteralExpressionImpl extends PyElementImpl implements PySt
List result = myValueTextRanges;
if (result == null) {
final int elementStart = getTextRange().getStartOffset();
- final List ranges = StreamEx.of(getGluedStringNodes())
+ final List ranges = StreamEx.of(getStringElements())
.map(node -> {
final int nodeRelativeOffset = node.getTextRange().getStartOffset() - elementStart;
return node.getContentRange().shiftRight(nodeRelativeOffset);
@@ -100,7 +100,7 @@ public class PyStringLiteralExpressionImpl extends PyElementImpl implements PySt
final int elementStart = getTextRange().getStartOffset();
List> result = myDecodedFragments;
if (result == null) {
- final List> combined = StreamEx.of(getGluedStringNodes())
+ final List> combined = StreamEx.of(getStringElements())
.flatMap(node -> StreamEx.of(node.getDecodedFragments())
.map(pair -> {
final int nodeRelativeOffset = node.getTextRange().getStartOffset() - elementStart;
@@ -127,10 +127,10 @@ public class PyStringLiteralExpressionImpl extends PyElementImpl implements PySt
@NotNull
@Override
- public List getGluedStringNodes() {
+ public List getStringElements() {
return StreamEx.of(getStringNodes())
.map(ASTNode::getPsi)
- .select(PyRichStringNode.class)
+ .select(PyStringElement.class)
.toList();
}
diff --git a/python/src/com/jetbrains/python/psi/impl/PythonASTFactory.java b/python/src/com/jetbrains/python/psi/impl/PythonASTFactory.java
index e88d52d14668..838c7bb72c86 100644
--- a/python/src/com/jetbrains/python/psi/impl/PythonASTFactory.java
+++ b/python/src/com/jetbrains/python/psi/impl/PythonASTFactory.java
@@ -16,7 +16,7 @@ public class PythonASTFactory extends ASTFactory {
@Override
public LeafElement createLeaf(@NotNull IElementType type, CharSequence text) {
if (PyTokenTypes.STRING_NODES.contains(type)) {
- return new PyLiteralStringNodeImpl(type, text);
+ return new PyPlainStringElementImpl(type, text);
}
return super.createLeaf(type, text);
}
diff --git a/python/src/com/jetbrains/python/validation/FStringsAnnotator.java b/python/src/com/jetbrains/python/validation/FStringsAnnotator.java
index 2747b4dc9a06..f6f61fa049b9 100644
--- a/python/src/com/jetbrains/python/validation/FStringsAnnotator.java
+++ b/python/src/com/jetbrains/python/validation/FStringsAnnotator.java
@@ -22,7 +22,7 @@ import com.intellij.psi.PsiElement;
import com.intellij.psi.util.PsiTreeUtil;
import com.jetbrains.python.psi.PyFStringFragment;
import com.jetbrains.python.psi.PyFStringFragmentFormatPart;
-import com.jetbrains.python.psi.PyFormattedStringNode;
+import com.jetbrains.python.psi.PyFormattedStringElement;
import com.jetbrains.python.psi.PyStringLiteralExpression;
import java.util.List;
@@ -70,7 +70,7 @@ public class FStringsAnnotator extends PyAnnotator {
}
@Override
- public void visitPyFormattedStringNode(PyFormattedStringNode node) {
+ public void visitPyFormattedStringElement(PyFormattedStringElement node) {
final String wholeNodeText = node.getText();
for (TextRange textRange : node.getLiteralPartRanges()) {
int i = textRange.getStartOffset();
diff --git a/python/src/com/jetbrains/python/validation/StringLiteralQuotesAnnotator.java b/python/src/com/jetbrains/python/validation/StringLiteralQuotesAnnotator.java
index fb18ef128d2f..11bfdff3f325 100644
--- a/python/src/com/jetbrains/python/validation/StringLiteralQuotesAnnotator.java
+++ b/python/src/com/jetbrains/python/validation/StringLiteralQuotesAnnotator.java
@@ -26,7 +26,7 @@ public class StringLiteralQuotesAnnotator extends PyAnnotator {
public void visitPyStringLiteralExpression(final PyStringLiteralExpression node) {
final List stringNodes = node.getStringNodes();
for (ASTNode stringNode : stringNodes) {
- // TODO Migrate to newer PyRichStringNode API
+ // TODO Migrate to newer PyStringElement API
if (stringNode.getElementType() == PyElementTypes.FSTRING_NODE) {
continue;
}
diff --git a/python/testData/psi/EmptyFStrings.txt b/python/testData/psi/EmptyFStrings.txt
index 9cd6d27a67fb..845fbd7eedc0 100644
--- a/python/testData/psi/EmptyFStrings.txt
+++ b/python/testData/psi/EmptyFStrings.txt
@@ -9,25 +9,25 @@ PyFile:EmptyFStrings.py
PsiElement(Py:LPAR)('(')
PyTupleExpression
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_END)(''')
PsiElement(Py:COMMA)(',')
PsiWhiteSpace('\n ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('F"')
PsiElement(Py:FSTRING_END)('"')
PsiElement(Py:COMMA)(',')
PsiWhiteSpace('\n ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('rf"""')
PsiElement(Py:FSTRING_END)('"""')
PsiElement(Py:COMMA)(',')
PsiWhiteSpace('\n ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('FR'''')
PsiElement(Py:FSTRING_END)(''''')
PsiElement(Py:COMMA)(',')
diff --git a/python/testData/psi/FStringAllKindsNested.txt b/python/testData/psi/FStringAllKindsNested.txt
index 04ab8c1c54f2..5fd1b90194c7 100644
--- a/python/testData/psi/FStringAllKindsNested.txt
+++ b/python/testData/psi/FStringAllKindsNested.txt
@@ -6,25 +6,25 @@ PyFile:FStringAllKindsNested.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: 1{f'''2{f"3{f'4'}"}'''}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PsiElement(Py:FSTRING_TEXT)('1')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: 2{f"3{f'4'}"}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PsiElement(Py:FSTRING_TEXT)('2')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: 3{f'4'}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PsiElement(Py:FSTRING_TEXT)('3')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: 4
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('4')
PsiElement(Py:FSTRING_END)(''')
diff --git a/python/testData/psi/FStringBackslashAfterExpression.txt b/python/testData/psi/FStringBackslashAfterExpression.txt
index e1bda69ea75e..1001175e4f25 100644
--- a/python/testData/psi/FStringBackslashAfterExpression.txt
+++ b/python/testData/psi/FStringBackslashAfterExpression.txt
@@ -6,7 +6,7 @@ PyFile:FStringBackslashAfterExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{42 \ }bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringBackslashBeforeExpression.txt b/python/testData/psi/FStringBackslashBeforeExpression.txt
index f73ca012a95c..045e6407112b 100644
--- a/python/testData/psi/FStringBackslashBeforeExpression.txt
+++ b/python/testData/psi/FStringBackslashBeforeExpression.txt
@@ -6,7 +6,7 @@ PyFile:FStringBackslashBeforeExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{\ 42}bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringBackslashInsideMultilineExpression.txt b/python/testData/psi/FStringBackslashInsideMultilineExpression.txt
index e116b140ebfd..c4363c0ee77b 100644
--- a/python/testData/psi/FStringBackslashInsideMultilineExpression.txt
+++ b/python/testData/psi/FStringBackslashInsideMultilineExpression.txt
@@ -7,7 +7,7 @@ PyFile:FStringBackslashInsideMultilineExpression.py
PsiWhiteSpace(' ')
PyStringLiteralExpression: { 1 + \
2}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringBackslashInsteadOfExpression.txt b/python/testData/psi/FStringBackslashInsteadOfExpression.txt
index 482527f0f306..f3c931c9ecae 100644
--- a/python/testData/psi/FStringBackslashInsteadOfExpression.txt
+++ b/python/testData/psi/FStringBackslashInsteadOfExpression.txt
@@ -6,7 +6,7 @@ PyFile:FStringBackslashInsteadOfExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{\}bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringContainsHashInLiteralPart.txt b/python/testData/psi/FStringContainsHashInLiteralPart.txt
index b81f2712c581..23773cfa431c 100644
--- a/python/testData/psi/FStringContainsHashInLiteralPart.txt
+++ b/python/testData/psi/FStringContainsHashInLiteralPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringContainsHashInLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: #foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('#foo')
PsiElement(Py:FSTRING_END)(''')
\ No newline at end of file
diff --git a/python/testData/psi/FStringContainsHashSignInFormatPart.txt b/python/testData/psi/FStringContainsHashSignInFormatPart.txt
index 0730cce92153..5211bf0b4025 100644
--- a/python/testData/psi/FStringContainsHashSignInFormatPart.txt
+++ b/python/testData/psi/FStringContainsHashSignInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringContainsHashSignInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:#b}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringDeeplyNestedEmptyFragments.txt b/python/testData/psi/FStringDeeplyNestedEmptyFragments.txt
index aebab178d631..48128ae32daf 100644
--- a/python/testData/psi/FStringDeeplyNestedEmptyFragments.txt
+++ b/python/testData/psi/FStringDeeplyNestedEmptyFragments.txt
@@ -6,7 +6,7 @@ PyFile:FStringDeeplyNestedEmptyFragments.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {:{:{:{}}}}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringEscapeSequenceInFormatPart.txt b/python/testData/psi/FStringEscapeSequenceInFormatPart.txt
index be962e70c91a..abacf667826d 100644
--- a/python/testData/psi/FStringEscapeSequenceInFormatPart.txt
+++ b/python/testData/psi/FStringEscapeSequenceInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringEscapeSequenceInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:\\\n}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringEscapeSequenceInLiteralPart.txt b/python/testData/psi/FStringEscapeSequenceInLiteralPart.txt
index f1890681af5e..5931e05ce23c 100644
--- a/python/testData/psi/FStringEscapeSequenceInLiteralPart.txt
+++ b/python/testData/psi/FStringEscapeSequenceInLiteralPart.txt
@@ -7,7 +7,7 @@ PyFile:FStringEscapeSequenceInLiteralPart.py
PsiWhiteSpace(' ')
PyStringLiteralExpression:
{42}\
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('\n')
PyFStringFragment
diff --git a/python/testData/psi/FStringEscapedBraces.txt b/python/testData/psi/FStringEscapedBraces.txt
index 92b1035c80a1..82a2a4f75c57 100644
--- a/python/testData/psi/FStringEscapedBraces.txt
+++ b/python/testData/psi/FStringEscapedBraces.txt
@@ -6,7 +6,7 @@ PyFile:FStringEscapedBraces.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {} {{42}} } {
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('{{}} {{')
PyFStringFragment
diff --git a/python/testData/psi/FStringEscapedLineBreakInLiteralPart.txt b/python/testData/psi/FStringEscapedLineBreakInLiteralPart.txt
index 625e0286dfd2..b156f3c5edfd 100644
--- a/python/testData/psi/FStringEscapedLineBreakInLiteralPart.txt
+++ b/python/testData/psi/FStringEscapedLineBreakInLiteralPart.txt
@@ -7,7 +7,7 @@ PyFile:FStringEscapedLineBreakInLiteralPart.py
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo
bar{42}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo\\nbar')
PyFStringFragment
diff --git a/python/testData/psi/FStringEscapedSlashBeforeClosingQuoteInFormatPart.txt b/python/testData/psi/FStringEscapedSlashBeforeClosingQuoteInFormatPart.txt
index 92f3f2d9ea3f..57481b80c69f 100644
--- a/python/testData/psi/FStringEscapedSlashBeforeClosingQuoteInFormatPart.txt
+++ b/python/testData/psi/FStringEscapedSlashBeforeClosingQuoteInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringEscapedSlashBeforeClosingQuoteInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:\\
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringExpressionContainBraces.txt b/python/testData/psi/FStringExpressionContainBraces.txt
index 054df29d69ce..9e51584539bc 100644
--- a/python/testData/psi/FStringExpressionContainBraces.txt
+++ b/python/testData/psi/FStringExpressionContainBraces.txt
@@ -6,7 +6,7 @@ PyFile:FStringExpressionContainBraces.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: { {1, 2} }
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentDuplicateTypeConversion.txt b/python/testData/psi/FStringFragmentDuplicateTypeConversion.txt
index 955e466694ca..1abeeba01131 100644
--- a/python/testData/psi/FStringFragmentDuplicateTypeConversion.txt
+++ b/python/testData/psi/FStringFragmentDuplicateTypeConversion.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentDuplicateTypeConversion.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!r!r}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentIllegalTypeConversion.txt b/python/testData/psi/FStringFragmentIllegalTypeConversion.txt
index c5a3d697bcd7..81abda07eb34 100644
--- a/python/testData/psi/FStringFragmentIllegalTypeConversion.txt
+++ b/python/testData/psi/FStringFragmentIllegalTypeConversion.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentIllegalTypeConversion.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!!}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingBrace.txt b/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingBrace.txt
index 272292a9e156..677bcfee63ce 100644
--- a/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingBrace.txt
+++ b/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingBrace.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentIncompleteTypeConversionBeforeClosingBrace.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingQuote.txt b/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingQuote.txt
index 14af2caae02a..0c3da00150c5 100644
--- a/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingQuote.txt
+++ b/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeClosingQuote.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentIncompleteTypeConversionBeforeClosingQuote.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeColon.txt b/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeColon.txt
index e5ae7d6e7c6f..d07bdf92a1b7 100644
--- a/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeColon.txt
+++ b/python/testData/psi/FStringFragmentIncompleteTypeConversionBeforeColon.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentIncompleteTypeConversionBeforeColon.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!:}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentTypeConversion.txt b/python/testData/psi/FStringFragmentTypeConversion.txt
index 7fe082745b4b..482ec7864be9 100644
--- a/python/testData/psi/FStringFragmentTypeConversion.txt
+++ b/python/testData/psi/FStringFragmentTypeConversion.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentTypeConversion.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!r}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentTypeConversionAfterFormatPart.txt b/python/testData/psi/FStringFragmentTypeConversionAfterFormatPart.txt
index f6be09e8314b..d2a8e10bdd11 100644
--- a/python/testData/psi/FStringFragmentTypeConversionAfterFormatPart.txt
+++ b/python/testData/psi/FStringFragmentTypeConversionAfterFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentTypeConversionAfterFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{width}!r}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentWithDictLiteral.txt b/python/testData/psi/FStringFragmentWithDictLiteral.txt
index 1e4f085d9d35..9fd8a4e458aa 100644
--- a/python/testData/psi/FStringFragmentWithDictLiteral.txt
+++ b/python/testData/psi/FStringFragmentWithDictLiteral.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentWithDictLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: { {1: 2} }
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentWithInterpolatedFormatPart.txt b/python/testData/psi/FStringFragmentWithInterpolatedFormatPart.txt
index 9bbb8b9e851b..5ac01ad265f8 100644
--- a/python/testData/psi/FStringFragmentWithInterpolatedFormatPart.txt
+++ b/python/testData/psi/FStringFragmentWithInterpolatedFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentWithInterpolatedFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: result: {value:{width}.{precision}}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('result: ')
PyFStringFragment
diff --git a/python/testData/psi/FStringFragmentWithLiteralFormatPart.txt b/python/testData/psi/FStringFragmentWithLiteralFormatPart.txt
index 976379769804..b442cf1e7f7f 100644
--- a/python/testData/psi/FStringFragmentWithLiteralFormatPart.txt
+++ b/python/testData/psi/FStringFragmentWithLiteralFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentWithLiteralFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:foo}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentWithNotParenthesizedLambda.txt b/python/testData/psi/FStringFragmentWithNotParenthesizedLambda.txt
index 195e47ef7456..8371f4a8d3c1 100644
--- a/python/testData/psi/FStringFragmentWithNotParenthesizedLambda.txt
+++ b/python/testData/psi/FStringFragmentWithNotParenthesizedLambda.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentWithNotParenthesizedLambda.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {lambda x: 42}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringFragmentWithParenthesizedLambda.txt b/python/testData/psi/FStringFragmentWithParenthesizedLambda.txt
index 994ded294687..81985f4ce4fb 100644
--- a/python/testData/psi/FStringFragmentWithParenthesizedLambda.txt
+++ b/python/testData/psi/FStringFragmentWithParenthesizedLambda.txt
@@ -6,7 +6,7 @@ PyFile:FStringFragmentWithParenthesizedLambda.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {(lambda x: 42)}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringGluedWithLiteralStringNodes.txt b/python/testData/psi/FStringGluedWithLiteralStringNodes.txt
index a6cac1e31dbd..620432490a2d 100644
--- a/python/testData/psi/FStringGluedWithLiteralStringNodes.txt
+++ b/python/testData/psi/FStringGluedWithLiteralStringNodes.txt
@@ -10,7 +10,7 @@ PyFile:FStringGluedWithLiteralStringNodes.py
PyStringLiteralExpression: foo{42} {True}bar
PsiElement(Py:SINGLE_QUOTED_STRING)(''foo'')
PsiWhiteSpace('\n ')
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringIncompleteFragment.txt b/python/testData/psi/FStringIncompleteFragment.txt
index 09594687c838..30cb442bba91 100644
--- a/python/testData/psi/FStringIncompleteFragment.txt
+++ b/python/testData/psi/FStringIncompleteFragment.txt
@@ -6,7 +6,7 @@ PyFile:FStringIncompleteFragment.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringIncompleteFragmentWithFormatPart.txt b/python/testData/psi/FStringIncompleteFragmentWithFormatPart.txt
index 3aa3ee08b504..7728db86468f 100644
--- a/python/testData/psi/FStringIncompleteFragmentWithFormatPart.txt
+++ b/python/testData/psi/FStringIncompleteFragmentWithFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringIncompleteFragmentWithFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{width}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringIncompleteFragmentWithTypeConversion.txt b/python/testData/psi/FStringIncompleteFragmentWithTypeConversion.txt
index 887c9ffd82c6..aae1992ae04d 100644
--- a/python/testData/psi/FStringIncompleteFragmentWithTypeConversion.txt
+++ b/python/testData/psi/FStringIncompleteFragmentWithTypeConversion.txt
@@ -6,7 +6,7 @@ PyFile:FStringIncompleteFragmentWithTypeConversion.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!r
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringIncompleteFragmentWithTypeConversionAndFormatPart.txt b/python/testData/psi/FStringIncompleteFragmentWithTypeConversionAndFormatPart.txt
index b1d87f930321..77a4c261ccec 100644
--- a/python/testData/psi/FStringIncompleteFragmentWithTypeConversionAndFormatPart.txt
+++ b/python/testData/psi/FStringIncompleteFragmentWithTypeConversionAndFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringIncompleteFragmentWithTypeConversionAndFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42!r:{width}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringIncompleteNamedUnicodePrecedingFragment.txt b/python/testData/psi/FStringIncompleteNamedUnicodePrecedingFragment.txt
index 1909b14bf3cc..c23350abb37d 100644
--- a/python/testData/psi/FStringIncompleteNamedUnicodePrecedingFragment.txt
+++ b/python/testData/psi/FStringIncompleteNamedUnicodePrecedingFragment.txt
@@ -6,7 +6,7 @@ PyFile:FStringIncompleteNamedUnicodePrecedingFragment.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: \N{LATIN SMALL LETTER A{42}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('\N{LATIN SMALL LETTER A')
PyFStringFragment
diff --git a/python/testData/psi/FStringNamedUnicodeEscapeInFormatPart.txt b/python/testData/psi/FStringNamedUnicodeEscapeInFormatPart.txt
index 129a4f868be2..483889eca4f4 100644
--- a/python/testData/psi/FStringNamedUnicodeEscapeInFormatPart.txt
+++ b/python/testData/psi/FStringNamedUnicodeEscapeInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringNamedUnicodeEscapeInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:\N{LATIN SMALL LETTER A}}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringNamedUnicodeEscapeInLiteralPart.txt b/python/testData/psi/FStringNamedUnicodeEscapeInLiteralPart.txt
index 5ff4194a58bd..f7ff4ece3fa9 100644
--- a/python/testData/psi/FStringNamedUnicodeEscapeInLiteralPart.txt
+++ b/python/testData/psi/FStringNamedUnicodeEscapeInLiteralPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringNamedUnicodeEscapeInLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('\N{LATIN SMALL LETTER A}')
PsiElement(Py:FSTRING_END)(''')
\ No newline at end of file
diff --git a/python/testData/psi/FStringNamedUnicodeEscapeInStringLiteral.txt b/python/testData/psi/FStringNamedUnicodeEscapeInStringLiteral.txt
index b036676b2195..f32585226501 100644
--- a/python/testData/psi/FStringNamedUnicodeEscapeInStringLiteral.txt
+++ b/python/testData/psi/FStringNamedUnicodeEscapeInStringLiteral.txt
@@ -6,7 +6,7 @@ PyFile:FStringNamedUnicodeEscapeInStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {"\N{LATIN SMALL LETTER A}"}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringSingleSlashBeforeLeftBraceInLiteralPart.txt b/python/testData/psi/FStringSingleSlashBeforeLeftBraceInLiteralPart.txt
index 4689a3d2236c..1b9f3bde7dd6 100644
--- a/python/testData/psi/FStringSingleSlashBeforeLeftBraceInLiteralPart.txt
+++ b/python/testData/psi/FStringSingleSlashBeforeLeftBraceInLiteralPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringSingleSlashBeforeLeftBraceInLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo\{42}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PsiElement(Py:FSTRING_TEXT)('\')
diff --git a/python/testData/psi/FStringSingleSlashesBeforeBracesInFormatPart.txt b/python/testData/psi/FStringSingleSlashesBeforeBracesInFormatPart.txt
index 25b1943bfa52..551ff80771fa 100644
--- a/python/testData/psi/FStringSingleSlashesBeforeBracesInFormatPart.txt
+++ b/python/testData/psi/FStringSingleSlashesBeforeBracesInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringSingleSlashesBeforeBracesInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:foo\{bar}baz\}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByEscapedLineBreakInNestedStringLiteral.txt b/python/testData/psi/FStringTerminatedByEscapedLineBreakInNestedStringLiteral.txt
index 394cc8ba393f..65967f0ef177 100644
--- a/python/testData/psi/FStringTerminatedByEscapedLineBreakInNestedStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByEscapedLineBreakInNestedStringLiteral.txt
@@ -7,13 +7,13 @@ PyFile:FStringTerminatedByEscapedLineBreakInNestedStringLiteral.py
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'''{'\
'}'''}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {'\
'}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInExpression.txt b/python/testData/psi/FStringTerminatedByLineBreakInExpression.txt
index 6242233bd2d6..b829fb7330da 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInExpression.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInExpression.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByLineBreakInExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInExpressionInFormatPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInExpressionInFormatPart.txt
index 992031e5c880..64d95df75947 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInExpressionInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInExpressionInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByLineBreakInExpressionInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInFormatPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInFormatPart.txt
index ae401a584597..d80071e7f63d 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByLineBreakInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{42:bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInLiteralPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInLiteralPart.txt
index a64e21cd7ea2..6b9b5e879170 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInLiteralPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInLiteralPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByLineBreakInLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PsiErrorElement:' expected
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInNestedExpression.txt b/python/testData/psi/FStringTerminatedByLineBreakInNestedExpression.txt
index ffb8e2b09fef..5447ab95f0b2 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInNestedExpression.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInNestedExpression.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByLineBreakInNestedExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'{1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInNestedExpressionInFormatPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInNestedExpressionInFormatPart.txt
index 674fe8725475..e19cc61d372d 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInNestedExpressionInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInNestedExpressionInFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByLineBreakInNestedExpressionInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'{42:{1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {42:{1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInNestedFormatPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInNestedFormatPart.txt
index 2730cc6437be..fc0af9d7a0f0 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInNestedFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInNestedFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByLineBreakInNestedFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'foo{42:bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: foo{42:bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInNestedLiteralPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInNestedLiteralPart.txt
index 34ee7f41a064..e09a8813496e 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInNestedLiteralPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInNestedLiteralPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByLineBreakInNestedLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PsiErrorElement:' expected
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInNestedStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInNestedStringLiteralInFormatPart.txt
index 8730e313c702..95f4bd132b08 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInNestedStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInNestedStringLiteralInFormatPart.txt
@@ -7,13 +7,13 @@ PyFile:FStringTerminatedByLineBreakInNestedStringLiteralInFormatPart.py
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'''{foo:{'\
'}}'''}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {foo:{'\
'}}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInStringLiteral.txt b/python/testData/psi/FStringTerminatedByLineBreakInStringLiteral.txt
index 56eea0784efb..99bd74d725ac 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInStringLiteral.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByLineBreakInStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {"""
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByLineBreakInStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByLineBreakInStringLiteralInFormatPart.txt
index 30a462bcd1ac..0f0ed9d1d79f 100644
--- a/python/testData/psi/FStringTerminatedByLineBreakInStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByLineBreakInStringLiteralInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByLineBreakInStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {foo:{"""
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteInFormatPart.txt
index 5e03320e310a..a975a34213bb 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteInLiteralPart.txt b/python/testData/psi/FStringTerminatedByQuoteInLiteralPart.txt
index 540d183b5fd6..da7219308c0a 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInLiteralPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInLiteralPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteInLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PsiElement(Py:FSTRING_END)(''')
diff --git a/python/testData/psi/FStringTerminatedByQuoteInNestedFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteInNestedFormatPart.txt
index b5243cd572fc..3f3ffbc09105 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInNestedFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInNestedFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteInNestedFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"{42:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {42:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteInNestedLiteralPart.txt b/python/testData/psi/FStringTerminatedByQuoteInNestedLiteralPart.txt
index ccb55f84c704..9675ec2bd3e5 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInNestedLiteralPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInNestedLiteralPart.txt
@@ -6,13 +6,13 @@ PyFile:FStringTerminatedByQuoteInNestedLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{f"baz
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: baz
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PsiElement(Py:FSTRING_TEXT)('baz')
PsiErrorElement:" expected
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteral.txt
index 66d25ef42434..bf884986177d 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteral.txt
@@ -6,13 +6,13 @@ PyFile:FStringTerminatedByQuoteInsideFStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{f"}baz'
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PsiErrorElement:" expected
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteralInFormatPart.txt
index a2330e7109ef..cbb21b7f499c 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideFStringLiteralInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteInsideFStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{f"}}'
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
@@ -17,7 +17,7 @@ PyFile:FStringTerminatedByQuoteInsideFStringLiteralInFormatPart.py
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PsiErrorElement:" expected
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteral.txt
index c720aaf1ba4d..37db2f2c21e2 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteral.txt
@@ -6,17 +6,17 @@ PyFile:FStringTerminatedByQuoteInsideNestedFStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"""{f"}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {f"
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PsiErrorElement:" expected
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteralInFormatPart.txt
index 60444a58ce0f..743ec94e6c7e 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideNestedFStringLiteralInFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteInsideNestedFStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"""{42:{f"}}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {42:{f"
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
@@ -22,7 +22,7 @@ PyFile:FStringTerminatedByQuoteInsideNestedFStringLiteralInFormatPart.py
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PsiErrorElement:" expected
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteral.txt
index a790a0a850f1..097b5798a111 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteral.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteInsideNestedStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"""{"}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {"
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteralInFormatPart.txt
index ec05c9aa1d10..158e00596978 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideNestedStringLiteralInFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteInsideNestedStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"""{42:{"}}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {42:{"
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteral.txt
index bf931d10d271..7fb645839a54 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteral.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteInsideStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{"}baz'
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteralInFormatPart.txt
index f2b7fcb788cd..3530a0992d28 100644
--- a/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteInsideStringLiteralInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteInsideStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{"}}'
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteral.txt
index 12cc335db71a..3a39b0205262 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteral.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteOfFStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{f
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteralInFormatPart.txt
index 4ceb077700e5..aa25103ec809 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfFStringLiteralInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteOfFStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{f
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteral.txt
index 850db5e29cd4..a65b59fc800f 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteral.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteOfNestedFStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"{f
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {f
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteralInFormatPart.txt
index 5df06336fe93..e5bee10dfd78 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfNestedFStringLiteralInFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteOfNestedFStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"{42:{f
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {42:{f
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteral.txt
index 1410056142df..02e2610e08cd 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteral.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteOfNestedStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"{
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteralInFormatPart.txt
index 627eeeabc7b7..d9687aac176c 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfNestedStringLiteralInFormatPart.txt
@@ -6,12 +6,12 @@ PyFile:FStringTerminatedByQuoteOfNestedStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f"{42:{
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {42:{
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfStringLiteral.txt b/python/testData/psi/FStringTerminatedByQuoteOfStringLiteral.txt
index 74581dce46ed..97debda75fbb 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfStringLiteral.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfStringLiteral.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteOfStringLiteral.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStringTerminatedByQuoteOfStringLiteralInFormatPart.txt b/python/testData/psi/FStringTerminatedByQuoteOfStringLiteralInFormatPart.txt
index 0435bfb49c26..6747e8531b5f 100644
--- a/python/testData/psi/FStringTerminatedByQuoteOfStringLiteralInFormatPart.txt
+++ b/python/testData/psi/FStringTerminatedByQuoteOfStringLiteralInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTerminatedByQuoteOfStringLiteralInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringTrailingWhitespaceInIncompleteFragmentInFormatPart.txt b/python/testData/psi/FStringTrailingWhitespaceInIncompleteFragmentInFormatPart.txt
index 726172984250..ceabcc400ca4 100644
--- a/python/testData/psi/FStringTrailingWhitespaceInIncompleteFragmentInFormatPart.txt
+++ b/python/testData/psi/FStringTrailingWhitespaceInIncompleteFragmentInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:FStringTrailingWhitespaceInIncompleteFragmentInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:{
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/FStringWithSimpleFragment.txt b/python/testData/psi/FStringWithSimpleFragment.txt
index b12a9e87a586..c4bc8605fbac 100644
--- a/python/testData/psi/FStringWithSimpleFragment.txt
+++ b/python/testData/psi/FStringWithSimpleFragment.txt
@@ -6,7 +6,7 @@ PyFile:FStringWithSimpleFragment.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: foo{42}bar
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PyFStringFragment
diff --git a/python/testData/psi/FStrings.txt b/python/testData/psi/FStrings.txt
index fc543bae3338..468c63a7fca9 100644
--- a/python/testData/psi/FStrings.txt
+++ b/python/testData/psi/FStrings.txt
@@ -6,7 +6,7 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_END)(''')
PsiWhiteSpace(' \n')
@@ -17,7 +17,7 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('fr'')
PsiElement(Py:FSTRING_END)(''')
PsiWhiteSpace('\n')
@@ -28,7 +28,7 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('rf'')
PsiElement(Py:FSTRING_END)(''')
PsiWhiteSpace('\n')
@@ -39,7 +39,7 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('F'')
PsiElement(Py:FSTRING_END)(''')
PsiWhiteSpace('\n')
@@ -50,7 +50,7 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('bf'')
PsiElement(Py:FSTRING_END)(''')
PsiWhiteSpace('\n')
@@ -61,7 +61,7 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('uf'')
PsiElement(Py:FSTRING_END)(''')
PsiWhiteSpace('\n')
@@ -72,6 +72,6 @@ PyFile:FStrings.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('ufr'')
PsiElement(Py:FSTRING_END)(''')
\ No newline at end of file
diff --git a/python/testData/psi/MultilineFStringContainingMultilineExpression.txt b/python/testData/psi/MultilineFStringContainingMultilineExpression.txt
index 2f682d935d8b..b611b58c1fea 100644
--- a/python/testData/psi/MultilineFStringContainingMultilineExpression.txt
+++ b/python/testData/psi/MultilineFStringContainingMultilineExpression.txt
@@ -7,7 +7,7 @@ PyFile:MultilineFStringContainingMultilineExpression.py
PsiWhiteSpace(' ')
PyStringLiteralExpression: {1 +
2}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/MultilineFStringContainingMultilineExpressionAfterStatementBreak.txt b/python/testData/psi/MultilineFStringContainingMultilineExpressionAfterStatementBreak.txt
index 86a567b46c54..a1a1229622aa 100644
--- a/python/testData/psi/MultilineFStringContainingMultilineExpressionAfterStatementBreak.txt
+++ b/python/testData/psi/MultilineFStringContainingMultilineExpressionAfterStatementBreak.txt
@@ -5,7 +5,7 @@ PyFile:MultilineFStringContainingMultilineExpressionAfterStatementBreak.py
PyExpressionStatement
PyStringLiteralExpression: {1 +
2}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/MultilineFStringContainsCommentInsideExpression.txt b/python/testData/psi/MultilineFStringContainsCommentInsideExpression.txt
index b8e069902589..8411d863a31b 100644
--- a/python/testData/psi/MultilineFStringContainsCommentInsideExpression.txt
+++ b/python/testData/psi/MultilineFStringContainsCommentInsideExpression.txt
@@ -8,7 +8,7 @@ PyFile:MultilineFStringContainsCommentInsideExpression.py
PyStringLiteralExpression: {[
# comment
]}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/MultilineFStringContainsCommentInsteadOfExpression.txt b/python/testData/psi/MultilineFStringContainsCommentInsteadOfExpression.txt
index 070b3bd15f27..0757aeea17e4 100644
--- a/python/testData/psi/MultilineFStringContainsCommentInsteadOfExpression.txt
+++ b/python/testData/psi/MultilineFStringContainsCommentInsteadOfExpression.txt
@@ -8,7 +8,7 @@ PyFile:MultilineFStringContainsCommentInsteadOfExpression.py
PyStringLiteralExpression: {
# comment
}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/MultilineFStringTerminatedByQuotesInsideParenthesizedExpression.txt b/python/testData/psi/MultilineFStringTerminatedByQuotesInsideParenthesizedExpression.txt
index 1b4351b88afe..8b63eb327bd3 100644
--- a/python/testData/psi/MultilineFStringTerminatedByQuotesInsideParenthesizedExpression.txt
+++ b/python/testData/psi/MultilineFStringTerminatedByQuotesInsideParenthesizedExpression.txt
@@ -6,7 +6,7 @@ PyFile:MultilineFStringTerminatedByQuotesInsideParenthesizedExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: { (lambda x:
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/MultilineFStringTerminatedByQuotesOfStringLiteral.txt b/python/testData/psi/MultilineFStringTerminatedByQuotesOfStringLiteral.txt
index c62aede695f6..00b5164fba7c 100644
--- a/python/testData/psi/MultilineFStringTerminatedByQuotesOfStringLiteral.txt
+++ b/python/testData/psi/MultilineFStringTerminatedByQuotesOfStringLiteral.txt
@@ -8,7 +8,7 @@ PyFile:MultilineFStringTerminatedByQuotesOfStringLiteral.py
PyStringLiteralExpression: {
}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/NestedMultilineFStringsWithMultilineExpressions.txt b/python/testData/psi/NestedMultilineFStringsWithMultilineExpressions.txt
index 6067cd514dab..9a4dd741fccd 100644
--- a/python/testData/psi/NestedMultilineFStringsWithMultilineExpressions.txt
+++ b/python/testData/psi/NestedMultilineFStringsWithMultilineExpressions.txt
@@ -10,7 +10,7 @@ PyFile:NestedMultilineFStringsWithMultilineExpressions.py
}
'''
}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
@@ -18,7 +18,7 @@ PyFile:NestedMultilineFStringsWithMultilineExpressions.py
{"bar"
}
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'''')
PsiElement(Py:FSTRING_TEXT)('\n')
PyFStringFragment
diff --git a/python/testData/psi/SetLiteral.txt b/python/testData/psi/SetLiteral.txt
index 9168cb3da5c5..d2e1df595a93 100644
--- a/python/testData/psi/SetLiteral.txt
+++ b/python/testData/psi/SetLiteral.txt
@@ -15,4 +15,4 @@ PyFile:SetLiteral.py
PsiElement(Py:LBRACE)('{')
PyNumericLiteralExpression
PsiElement(Py:INTEGER_LITERAL)('1')
- PsiElement(Py:RBRACE)('}')
\ No newline at end of file
+ PsiElement(Py:RBRACE)('}')
\ No newline at end of file
diff --git a/python/testData/psi/SingleLineFStringContainsCommentInsideExpression.txt b/python/testData/psi/SingleLineFStringContainsCommentInsideExpression.txt
index 3792c05417a7..c814104e108c 100644
--- a/python/testData/psi/SingleLineFStringContainsCommentInsideExpression.txt
+++ b/python/testData/psi/SingleLineFStringContainsCommentInsideExpression.txt
@@ -6,7 +6,7 @@ PyFile:SingleLineFStringContainsCommentInsideExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42 # comment}'
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/SingleLineFStringContainsCommentInsteadOfExpression.txt b/python/testData/psi/SingleLineFStringContainsCommentInsteadOfExpression.txt
index 03d98b279ebd..5d6c8c935987 100644
--- a/python/testData/psi/SingleLineFStringContainsCommentInsteadOfExpression.txt
+++ b/python/testData/psi/SingleLineFStringContainsCommentInsteadOfExpression.txt
@@ -6,7 +6,7 @@ PyFile:SingleLineFStringContainsCommentInsteadOfExpression.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {# comment}'
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpression.txt b/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpression.txt
index d55092ff1206..f34976740209 100644
--- a/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpression.txt
+++ b/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpression.txt
@@ -6,12 +6,12 @@ PyFile:SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpressio
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'{1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpressionInParentheses.txt b/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpressionInParentheses.txt
index fb8e01f7a31c..a37ee8a2f6cb 100644
--- a/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpressionInParentheses.txt
+++ b/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpressionInParentheses.txt
@@ -6,12 +6,12 @@ PyFile:SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInExpressio
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'{(1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: {(1 +
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInText.txt b/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInText.txt
index 7cdfc4afa83c..2957ab61690d 100644
--- a/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInText.txt
+++ b/python/testData/psi/SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInText.txt
@@ -6,12 +6,12 @@ PyFile:SingleQuotedFStringInsideMultilineFStringTerminatedByLineBreakInText.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {f'foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f"""')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
PyStringLiteralExpression: foo
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('foo')
PsiErrorElement:' expected
diff --git a/python/testData/psi/UnterminatedFStringWithTrailingBackslashInFormatPart.txt b/python/testData/psi/UnterminatedFStringWithTrailingBackslashInFormatPart.txt
index 2e581960c94e..4d866f16b1a1 100644
--- a/python/testData/psi/UnterminatedFStringWithTrailingBackslashInFormatPart.txt
+++ b/python/testData/psi/UnterminatedFStringWithTrailingBackslashInFormatPart.txt
@@ -6,7 +6,7 @@ PyFile:UnterminatedFStringWithTrailingBackslashInFormatPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: {42:\
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PyFStringFragment
PsiElement(Py:FSTRING_FRAGMENT_START)('{')
diff --git a/python/testData/psi/UnterminatedFStringWithTrailingBackslashInLiteralPart.txt b/python/testData/psi/UnterminatedFStringWithTrailingBackslashInLiteralPart.txt
index 869c9fc5b1e0..bc2f0d7238b9 100644
--- a/python/testData/psi/UnterminatedFStringWithTrailingBackslashInLiteralPart.txt
+++ b/python/testData/psi/UnterminatedFStringWithTrailingBackslashInLiteralPart.txt
@@ -6,7 +6,7 @@ PyFile:UnterminatedFStringWithTrailingBackslashInLiteralPart.py
PsiElement(Py:EQ)('=')
PsiWhiteSpace(' ')
PyStringLiteralExpression: \
- PyFormattedStringNode
+ PyFormattedStringElement
PsiElement(Py:FSTRING_START)('f'')
PsiElement(Py:FSTRING_TEXT)('\')
PsiErrorElement:' expected
diff --git a/python/testSrc/com/jetbrains/python/PyStringLiteralTest.java b/python/testSrc/com/jetbrains/python/PyStringLiteralTest.java
index dc171411cc64..93b4210f411f 100644
--- a/python/testSrc/com/jetbrains/python/PyStringLiteralTest.java
+++ b/python/testSrc/com/jetbrains/python/PyStringLiteralTest.java
@@ -179,6 +179,6 @@ public class PyStringLiteralTest extends PyTestCase {
public void testRichStringNodes() {
final PyStringLiteralExpression string = createLiteralFromText("'foo' 'bar' 'baz'");
- assertSize(3, string.getGluedStringNodes());
+ assertSize(3, string.getStringElements());
}
}
diff --git a/python/psi-api/src/com/jetbrains/python/psi/PyStringLiteralExpression.java b/python/psi-api/src/com/jetbrains/python/psi/PyStringLiteralExpression.java
index 510e4520c745..80e6b131eac9 100644
--- a/python/psi-api/src/com/jetbrains/python/psi/PyStringLiteralExpression.java
+++ b/python/psi-api/src/com/jetbrains/python/psi/PyStringLiteralExpression.java
@@ -37,17 +37,17 @@ import java.util.List;
* a "raw" bytes literal {@code rb'\bar'} using apostrophes as quotes and a formatted string literal
* {@code f'{baz}'} containing the value of the expression {@code baz}.
*
* PSI elements representing each of these parts can be acquired using {@link #getGluedStringNodes()} method.
* Both plain and formatted literals forming a whole string literal expression implement {@link PyRichStringNode}
* interface containing methods for retrieving general information about them such as quote types, prefixes,
* decoded value, etc.
*
* @see
* https://docs.python.org/3/reference/lexical_analysis.html#string-literal-concatenation
- * @see #getGluedStringNodes()
- * @see PyRichStringNode
- * @see PyLiteralStringNode
- * @see PyFormattedStringNode
+ * @see #getStringElements()
+ * @see PyStringElement
+ * @see PyPlainStringElement
+ * @see PyFormattedStringElement
*/
public interface PyStringLiteralExpression extends PyLiteralExpression, StringLiteralExpression, PsiLanguageInjectionHost {
@NotNull
@@ -57,7 +57,7 @@ public interface PyStringLiteralExpression extends PyLiteralExpression, StringLi
* Returns a list of implicitly concatenated string elements composing this literal expression.
*/
@NotNull
- List getGluedStringNodes();
+ List getStringElements();
int valueOffsetToTextOffset(int valueOffset);
@@ -37,17 +37,17 @@ import java.util.List;
* {@code f'{baz}'} containing the value of the expression {@code baz}.
*
- * PSI elements representing each of these parts can be acquired using {@link #getGluedStringNodes()} method.
- * Both plain and formatted literals forming a whole string literal expression implement {@link PyRichStringNode}
+ * PSI elements representing each of these parts can be acquired using {@link #getStringElements()} method.
+ * Both plain and formatted literals forming a whole string literal expression implement {@link PyStringElement}
* interface containing methods for retrieving general information about them such as quote types, prefixes,
* decoded value, etc.